@@ -7,16 +7,18 @@ import logging
 
 import urllib
 
-from tiddlyweb import control
 from tiddlyweb.web.http import HTTP400
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.policy import ForbiddenError, UserRequiredError
 from tiddlyweb.store import StoreMethodNotImplemented
-from tiddlyweb.web import util as web
 from tiddlyweb.web.sendtiddlers import send_tiddlers
 
 
 def get_search_query(environ):
+    """
+    Inspect tiddlyweb.query in the environment to get
+    the search query.
+    """
     try:
         search_query = environ['tiddlyweb.query']['q'][0]
         search_query = urllib.unquote(search_query)
@@ -24,7 +26,13 @@ def get_search_query(environ):
         raise HTTP400('query string required')
     return search_query
 
+
 def get_tiddlers(environ):
+    """
+    Call search in the store with search query to
+    get the generator of tiddlers matching the
+    query.
+    """
     search_query = get_search_query(environ)
     store = environ['tiddlyweb.store']
     try:
@@ -34,6 +42,7 @@ def get_tiddlers(environ):
         raise HTTP400('Search system not implemented')
     return tiddlers
 
+
 def get(environ, start_response):
     """
     Perform a search on the store. What search
